EventLogPlatform class abstract

The interface that platform-specific implementations of event_log must extend.

Platform implementations should extend this class rather than implement it as event_log does not consider newly added methods to be breaking changes. Extending this class (using extends) ensures that the subclass will get the default implementation, while platform implementations that implements this interface will be broken by newly added EventLogPlatform methods.

Inheritance
  • Object
  • PlatformInterface
  • EventLogPlatform
Implementers

Constructors

EventLogPlatform()
Constructs a EventLogPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearChannel(String channel, {String? backupPath}) Future<void>
Clears all events from the specified channel.
getChannelInfo(String channelName) Future<ChannelInfo?>
Gets information about a specific channel.
getEventById(int eventRecordId, {String? channel}) Future<EventRecord?>
Retrieves a single event by its record ID.
getEventStream() Stream<EventRecord>
Gets the stream of events for real-time subscriptions.
getEventStreamForSubscription(String subscriptionId) Stream<EventRecord>
Gets the stream of events for a specific subscription.
listChannels() Future<List<ChannelInfo>>
Lists all available event log channels on the system.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryEvents(EventFilter filter) Future<List<EventRecord>>
Queries historical events from the event log.
subscribeToEvents(EventFilter filter) Future<String>
Subscribes to real-time events from the event log.
toString() String
A string representation of this object.
inherited
unsubscribe(String subscriptionId) Future<void>
Unsubscribes from a real-time event subscription.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance EventLogPlatform
The default instance of EventLogPlatform to use.
getter/setter pair