MethodChannelEventLog class
An implementation of EventLogPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- EventLogPlatform
- MethodChannelEventLog
Constructors
Properties
- eventChannel → EventChannel
-
The event channel for receiving real-time events.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearChannel(
String channel, {String? backupPath}) → Future< void> -
Clears all events from the specified channel.
override
-
getChannelInfo(
String channelName) → Future< ChannelInfo?> -
Gets information about a specific channel.
override
-
getEventById(
int eventRecordId, {String? channel}) → Future< EventRecord?> -
Retrieves a single event by its record ID.
override
-
getEventStream(
) → Stream< EventRecord> -
Gets the stream of events for real-time subscriptions.
override
-
getEventStreamForSubscription(
String subscriptionId) → Stream< EventRecord> -
Gets the stream of events for a specific subscription.
override
-
listChannels(
) → Future< List< ChannelInfo> > -
Lists all available event log channels on the system.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryEvents(
EventFilter filter) → Future< List< EventRecord> > -
Queries historical events from the event log.
override
-
subscribeToEvents(
EventFilter filter) → Future< String> -
Subscribes to real-time events from the event log.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
String subscriptionId) → Future< void> -
Unsubscribes from a real-time event subscription.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited