clearChannel method
Clears all events from the specified channel.
channel is the name of the channel to clear.
backupPath is an optional path to save the events before clearing.
Throws EventLogException if the operation fails.
Implementation
Future<void> clearChannel(String channel, {String? backupPath}) {
throw UnimplementedError('clearChannel() has not been implemented.');
}